import React, { CSSProperties } from 'react';
import './styles/tailwind.css';
import './styles/loader.css';
export interface NftGalleryProps {
    /**
     * Ethereum address (`0x...`) or ENS domain (`vitalik.eth`) for which the gallery should contain associated NFTs.
     * Required.
     */
    ownerAddress: string;
    /**
     * Display asset metadata underneath the NFT.
     * Defaults to `true`.
     */
    metadataIsVisible?: boolean;
    /**
     * Display gallery in dark mode.
     * Defaults to `false`.
     */
    darkMode?: boolean;
    /**
     * Display gallery in showcase mode. Only NFTs specified in `showcaseItemIds` will be rendered.
     * Defaults to `false`.
     */
    showcaseMode?: boolean;
    /**
     * An array of IDs for assets that should be displayed when `showcaseMode` is active.
     * Each ID is formed by combining the asset's contract address and the asset's own tokenId: `{:assetContractAddress}/{:tokenId}`
     *
     * For example:
     *
     * ```jsx
     * showcaseItemIds={["0xabcdef.../123", "0xa1b2c3.../789"]}
     * ```
     */
    showcaseItemIds?: string[];
    /**
     * Enables/disables the lightbox being shown when a gallery item is clicked/tapped.
     * Defaults to `true`.
     */
    hasLightbox?: boolean;
    /**
     * Enables/disables a gallery item's title and collection name linking to the asset and collection on OpenSea, respectively.
     * Defaults to `true`.
     */
    hasExternalLinks?: boolean;
    /**
     * Renders the gallery as a single row with horizontal scrolling. Useful when rendering the gallery between other content.
     * Defaults to `false`.
     */
    isInline?: boolean;
    /**
     * Disables lazy loading and shows a "Load more" button to fetch the next set of gallery items.
     * Defaults to `false`.
     */
    hasLoadMoreButton?: boolean;
    /**
     * Overrides the default styling of the gallery's container.
     */
    galleryContainerStyle?: CSSProperties;
    /**
     * Overrides the default styling of all gallery item containers.
     */
    itemContainerStyle?: CSSProperties;
    /**
     * Overrides the default styling of all gallery item image containers.
     */
    imgContainerStyle?: CSSProperties;
}
export declare const NftGallery: React.FC<NftGalleryProps>;
